﻿' *****************************************************************************
' IIS Tweak
' A simple utility that allows you to re-configure an IIS web site with
' user-defined settings at the click of a button.
'
' Developed by Mark Gilbert (http://www.mark-gilbert.com).
'
' This software is license under the Microsoft Public License (Ms-PL).  For full
' license details, please see 
' http://www.microsoft.com/resources/sharedsource/licensingbasics/publiclicense.mspx.
' *****************************************************************************

''' <summary>
''' This encapsulates the logic for a single web site to be shown in a treeview.
''' </summary>
''' <remarks></remarks>
Public Class SiteNode
    Inherits TreeNode

    Private _DisplayName As String
    Private _Path As String


#Region " Custom Exceptions "
    Public Class InvalidDisplayNameException
        Inherits Exception

        Public Sub New()
            MyBase.New("Site name cannot be empty.")
        End Sub
    End Class


    Public Class InvalidPathException
        Inherits Exception

        Public Sub New()
            MyBase.New("Path to site cannot be empty.")
        End Sub
    End Class
#End Region


    Public Sub New(ByVal DisplayName As String, ByVal Path As String)
        MyBase.New(DisplayName)

        If (IsNothing(DisplayName)) Then DisplayName = ""
        If (DisplayName.Trim.Length = 0) Then Throw New InvalidDisplayNameException

        If (IsNothing(Path)) Then Path = ""
        If (Path.Trim.Length = 0) Then Throw New InvalidPathException

        Me._DisplayName = DisplayName
        Me._Path = Path
    End Sub


#Region " Properties "
    Public Property DisplayName() As String
        Get
            If (IsNothing(Me._DisplayName)) Then Me._DisplayName = ""
            Return Me._DisplayName.Trim
        End Get
        Set(ByVal value As String)
            If (IsNothing(value)) Then value = ""
            If (value.Trim.Length = 0) Then Throw New InvalidDisplayNameException

            Me._DisplayName = value.Trim
        End Set
    End Property


    Public Property Path() As String
        Get
            If (IsNothing(Me._Path)) Then Me._Path = ""
            Return Me._Path.Trim
        End Get
        Set(ByVal value As String)
            If (IsNothing(value)) Then value = ""
            If (value.Trim.Length = 0) Then Throw New InvalidPathException

            Me._Path = value.Trim
        End Set
    End Property

    Public ReadOnly Property Value() As String
        Get
            Return Me.Path
        End Get
    End Property

#End Region


#Region " Methods "
    Public Overrides Function ToString() As String
        Return Me.DisplayName
    End Function
#End Region


End Class
